@@ -45,6 +45,11 @@ func doCreatePodIdentityAssociation(cmd *cmdutils.Cmd) error {
 		return err
 	}
 
+	clientSet, err := ctl.NewStdClientSet(cfg)
+	if err != nil {
+		return err
+	}
+
 	isInstalled, err := podidentityassociation.IsPodIdentityAgentInstalled(ctx, ctl.AWSProvider.EKS(), cfg.Metadata.Name)
 	if err != nil {
 		return err
@@ -55,7 +60,7 @@ func doCreatePodIdentityAssociation(cmd *cmdutils.Cmd) error {
 		return api.ErrPodIdentityAgentNotInstalled(suggestion)
 	}
 
-	return podidentityassociation.NewCreator(cmd.ClusterConfig.Metadata.Name, ctl.NewStackManager(cfg), ctl.AWSProvider.EKS()).
+	return podidentityassociation.NewCreator(cmd.ClusterConfig.Metadata.Name, ctl.NewStackManager(cfg), ctl.AWSProvider.EKS(), clientSet).
 		CreatePodIdentityAssociations(ctx, cmd.ClusterConfig.IAM.PodIdentityAssociations)
 }
 
